[![pypi](https://img.shields.io/pypi/v/lamin-logger?color=%2334D058&label=pypi%20package)](https://pypi.org/project/lamin-logger)

# Lamin Logger: Logging setup

This package is in private beta at this moment!

Follow https://twitter.com/laminlabs to learn about a first public release.

For beta users: Read the [docs](https://lamin.ai/docs/lamin-logger).
